define(
//begin v1.x content
({
	"descTemplate": "${2} - ${3} od ${1} ${0}",
	"firstTip": "Prva stranica",
	"lastTip": "Zadnja stranica",
	"nextTip": "Sljedeća stranica",
	"prevTip": "Prethodna stranica",
	"itemTitle": "stavke",
	"singularItemTitle": "stavka",
	"pageStepLabelTemplate": "Strana ${0}",
	"pageSizeLabelTemplate": "${0} stavki po stranici",
	"allItemsLabelTemplate": "Sve stavke",
	"gotoButtonTitle": "Idi na određenu stranicu",
	"dialogTitle": "Idi na stranicu",
	"dialogIndication": "Navedite broj stranice",
	"pageCountIndication": " (${0} stranica)",
	"dialogConfirm": "Idi",
	"dialogCancel": "Opoziv",
	"all": "svi"
})
//end v1.x content
);

